==> sitemap-1.1.zip: modules/sitemap/language/italian/modinfo.php <==
<?php
/*************************************************************************/
# Italian Language Pack for module:                                      #
# Sitemap                                                                #
#                                                                        #
# Author                                                                 #
# flying.tux     -   flying.tux@gmail.com                                #
#                                                                        #
# Last modified on 12.04.2005                                            #
/*************************************************************************/
define('_MI_SITEMAP_NAME', 'Mappa del sito');
define('_MI_SITEMAP_MESSAGE', 'Messaggio');

define('_MI_MESSAGE', 'Messaggio');
define('_MI_MESSAGEEDSC', 'Messaggio visualizzato sulla pagina');

define('_MI_SHOW_SUBCATEGORIES', 'Visualizza sotto categorie');
define('_MI_SHOW_SUBCATEGORIESDSC', '');

define('_MI_ALLTIME_GUEST', 'Sempre in modalit ospite');
define('_MI_ALLTIME_GUESTDSC', "Se la cache del modulo  abilitata, impostare questa opzione su 'si'");

define('_MI_INVISIBLE_WEIGHTS', 'Pesi dei moduli nascosti');
define('_MI_INVISIBLE_WEIGHTSDSC', 'I moduli i cui pesi, nel menu di amministrazione, sono impostati col valore indicato non saranno visualizzati.<br />I singoli pesi devono essere separati da una virgola.<br />(Normalmente 0 oppure vuoto)');

define('_MI_INVISIBLE_DIRNAMES', 'Nome cartella dei moduli nascosti');
define('_MI_INVISIBLE_DIRNAMESDSC', "Specificare il nome dei moduli da nascondere.<br />I nomi delle cartelle devono essere separati da una virgola.<br />(Esempio: xoopsheadline,newbb)");

?>

==> sitemap-1.3.zip: modules/sitemap/language/italian/modinfo.php <==
<?php
/*************************************************************************/
# Italian Language Pack for module:                                      #
# Sitemap                                                                #
#                                                                        #
# Author                                                                 #
# flying.tux     -   flying.tux@gmail.com                                #
#                                                                        #
# Last modified on 12.04.2005                                            #
/*************************************************************************/


// Appended by Xoops Language Checker -GIJOE- in 2006-10-28 05:37:02
define('_MI_SITEMAP_ADMENU_TOP','TOP');

// Appended by Xoops Language Checker -GIJOE- in 2005-09-03 06:21:32
define('_MI_SITEMAP_ADMENU_MYBLOCKSADMIN','Blocks/Groups');
define('_MI_SITEMAP_BLOCKNAME','Sitemap');
define('_MI_SITEMAP_BLOCKDESC','Show sitemap as a block.');

define('_MI_SITEMAP_NAME', 'Mappa del sito');
define('_MI_SITEMAP_MESSAGE', 'Messaggio');

define('_MI_MESSAGE', 'Messaggio');
define('_MI_MESSAGEEDSC', 'Messaggio visualizzato sulla pagina');

define('_MI_SHOW_SUBCATEGORIES', 'Visualizza sotto categorie');
define('_MI_SHOW_SUBCATEGORIESDSC', '');

define('_MI_ALLTIME_GUEST', 'Sempre in modalit ospite');
define('_MI_ALLTIME_GUESTDSC', "Se la cache del modulo  abilitata, impostare questa opzione su 'si'");

define('_MI_INVISIBLE_WEIGHTS', 'Pesi dei moduli nascosti');
define('_MI_INVISIBLE_WEIGHTSDSC', 'I moduli i cui pesi, nel menu di amministrazione, sono impostati col valore indicato non saranno visualizzati.<br />I singoli pesi devono essere separati da una virgola.<br />(Normalmente 0 oppure vuoto)');

define('_MI_INVISIBLE_DIRNAMES', 'Nome cartella dei moduli nascosti');
define('_MI_INVISIBLE_DIRNAMESDSC', "Specificare il nome dei moduli da nascondere.<br />I nomi delle cartelle devono essere separati da una virgola.<br />(Esempio: xoopsheadline,newbb)");

?>
